# This software is licensed by the MIT License (MIT), see LICENSE file
#               Copyright © 2024 Gregory Lirent <opensource@lirent.ru>

from django.conf import settings
from django.utils.translation import gettext_lazy as _
from django.db import models

from .. import decorators
from ..page import OGSubpage
from .properties import OGContactData, OGPlace


@decorators.OGClass('business:contact_data', ('page', 'contact_data', 'locality', 'region', 'postal_code', 'country_name'))
class OGBusinessPage(OGSubpage):
    """
    URI: https://developers.facebook.com/blog/post/2013/06/05/platform-updates--new-open-graph-business-object-type/
    _________________________________________

    Entities:

    business:contact_data:... -> see ./properties/contact_data.py
    place:location::...       -> see ./properties/place.py

    _________________________________________
    """

    class Meta:
        db_table = 'businesses'
        app_label = settings.get('OPENGRAPH_META_APP_LABEL', 'opengraph')
        verbose_name = _('business meta information')
        verbose_name_plural = _('businesses meta information')

    contact_data = models.ForeignKey(OGContactData, on_delete=models.CASCADE, verbose_name=_('contact data'))
    place = models.ForeignKey(OGPlace, on_delete=models.SET_NULL, null=True, verbose_name=_('place'))

    def __init__(self, *args, **kwargs):
        kwargs['page_type'] = 'business.business'
        super().__init__(*args, **kwargs)
