# This software is licensed by the MIT License (MIT), see LICENSE file
#               Copyright © 2024 Gregory Lirent <opensource@lirent.ru>

from django.conf import settings
from django.utils.translation import gettext_lazy as _
from django.db import models

from ... import decorators


@decorators.OGClass('place', ('latitude', 'longitude'))
class OGPlace(models.Model):
    """
    URI: https://developers.facebook.com/blog/post/2013/06/05/platform-updates--new-open-graph-business-object-type/
    _________________________________________

    Entities:

    place:location:latitude
    place:location:longitude

    _________________________________________
    """

    class Meta:
        db_table = 'places'
        app_label = settings.get('OPENGRAPH_META_APP_LABEL', 'opengraph')
        verbose_name = _('place geographic information')
        verbose_name_plural = _('places geographic information')

    latitude = models.DecimalField(_('latitude'), decimal_places=10, max_digits=13)
    longitude = models.DecimalField(_('longitude'), decimal_places=10, max_digits=13)

    @classmethod
    def og_processing(cls, k, v, obj):
        k = k.split(':')
        if k[-1] in ('latitude', 'longitude'):
            k.insert(len(k) - 1, 'location')
            v = str(round(v, 10)).rstrip('0')
        yield ':'.join(k), v
