# This software is licensed by the MIT License (MIT), see LICENSE file
#               Copyright © 2024 Gregory Lirent <opensource@lirent.ru>

from django.conf import settings
from django.utils.translation import gettext_lazy as _
from django.db import models
from django.db.models.functions import Lower

from .. import decorators


@decorators.OGClass
class OGTag(models.Model):

    class Meta:
        db_table = 'tags'
        app_label = settings.get('OPENGRAPH_META_APP_LABEL', 'opengraph')
        verbose_name = _('meta keyword')
        verbose_name_plural = _('meta keywords')
        constraints = [models.UniqueConstraint(Lower('name'), name='og_unique_tag_name')]

    name = models.CharField(_('name'), max_length=32)

    def __str__(self):
        return self.name
