# This software is licensed by the MIT License (MIT), see LICENSE file
#               Copyright © 2024 Gregory Lirent <opensource@lirent.ru>

from django.conf import settings
from django.utils.translation import gettext_lazy as _
from django.db import models

from ... import decorators


@decorators.OGClass(':player', ('!url', 'width', 'height', 'stream'))
class TwitterCardPlayer(models.Model):
    """
    URI: https://developers.facebook.com/blog/post/2013/06/05/platform-updates--new-open-graph-business-object-type/
    _________________________________________

    Entities:

    ...:player        -> HTTPS URL of player iframe
    ...:player:width  -> Width of iframe in pixels
    ...:player:height -> Height of iframe in pixels
    ...:player:stream -> URL to raw video or audio stream

    _________________________________________
    """

    class Meta:
        db_table = 'player'
        app_label = settings.get('TWITTER_CARD_META_APP_LABEL', 'twitter_card')
        verbose_name = _('player meta information')
        verbose_name_plural = _('players meta information')

    url = models.URLField(_('url'))
    stream = models.URLField(_('stream url'), null=True)
    width = models.PositiveSmallIntegerField(_('width'))
    height = models.PositiveSmallIntegerField(_('height'))
